# FirstProjectPython
Módulo para construção de projetos Python.


[![Updates](https://pyup.io/repos/github/DanielDevMatos/FirstProjectPython/shield.svg)](https://pyup.io/repos/github/DanielDevMatos/FirstProjectPython/)
[![Python 3](https://pyup.io/repos/github/DanielDevMatos/FirstProjectPython/python-3-shield.svg)](https://pyup.io/repos/github/DanielDevMatos/FirstProjectPython/)

Suportada versão 3.10 de python

Para instalar:
"""Console
python3 -m venv .venv
source .venv\scripts\activate
pip install -r requirements-dev.txt
"""

Para conferir qualidade de código:
'''comando
flake8
'''
